#
# spec file for package rr
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rr
Version:        5.3.0
Release:        lp152.1.2
Summary:        Records nondeterministic executions and debugs them deterministically
License:        MIT
Group:          Development/Languages/C and C++
URL:            https://rr-project.org/
Source:         https://github.com/mozilla/%{name}/archive/%{version}.tar.gz
BuildRequires:  capnproto
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gdb
BuildRequires:  libcapnp-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  python3-pexpect
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(zlib)
ExclusiveArch:  x86_64 %{ix86}
%ifarch x86_64
BuildRequires:  gcc-c++-32bit
%endif

%description
This program aspires to be your primary debugging tool, enhancing gdb. It
also provides efficient reverse execution under gdb. Set breakpoints and
data watchpoints and quickly reverse-execute to where they were hit.

%prep
%setup -q

%build
# Fix incorrect path to bash
sed -i "s|%{_bindir}/bash|/bin/bash|g" ./scripts/signal-rr-recording.sh
sed -i "s|#!.*/usr/bin/env.*|#!%{_bindir}/python3|" scripts/rr-collect-symbols.py
CXXFLAGS=-std=c++14 %cmake \
  -DBUILD_TESTS=OFF
CXXFLAGS=-std=c++14 %make_jobs

%install
%cmake_install

%files
%license LICENSE
%doc README.md
%dir %{_datadir}/rr
%dir %{_libdir}/rr
%{_bindir}/rr
%{_bindir}/rr_exec_stub*
%{_bindir}/rr_page_*
%{_bindir}/signal-rr-recording.sh
%{_datadir}/rr/*
%{_libdir}/rr/librrpreload*.so
%{_datadir}/bash-completion/completions/rr
%{_bindir}/rr-collect-symbols.py

%changelog
* Wed Dec 18 2019 Michael Vetter <mvetter@suse.com>
- Update to 5.3.0:
  * This is primarily a maintenance release.
    There are many bug fixes, improvements to system call coverage,
  and incremental performance improvements.
  * The rr sources, rr buildid and rr traceinfo commands have been
    added to make it easier for external tools to work with rr
  traces. rr ls has been added to improve management of traces.
- Remove:
  * rr-5.2.0-cpp14.patch
  * rr-5.2.0-python3.patch
  * rr-5.2.0-remove-ucontext.patch
* Tue Dec 17 2019 Michael Vetter <mvetter@suse.com>
- Add rr-5.2.0-python3.patch
  We remove Python2 soon.
  Backport Python3 changes planned for next release only.
  See https://github.com/mozilla/rr/issues/2390
* Tue Dec 17 2019 Michael Vetter <mvetter@suse.com>
- Add patches to fix build:
  * rr-5.2.0-cpp14.patch
    See https://github.com/mozilla/rr/issues/2391
  * rr-5.2.0-remove-ucontext.patch
    See https://github.com/mozilla/rr/issues/2269
* Wed Oct  9 2019 mvetter@suse.com
- Update to 5.2.0:
  * Improvements to chaos mode.
  * Improvements to trace portability:
    https://robert.ocallahan.org/2018/04/cpuid-features-xsave-and-rr-trace.html
  * Various bug fixes.
* Thu Dec 14 2017 mvetter@suse.com
- Update to 5.1.0:
  * gdb info proc map supported
  * Maintenance update to handle issues arising from Ubuntu 17.10 and Fedora 27
  * Various bugs fixed
- Remove rr-shared.patch: contained in upstream
* Mon Nov 27 2017 mpluskal@suse.com
- Cleanup with spec-cleaner
- Use more cmake macros:
  * rr-shared.patch
  * Disable building of tests as it breaks with our optflags
- Fix dependency on /usr/bin/bash
- Build also 32-bit support
- Limit to building on supported platforms
* Wed Oct 25 2017 mvetter@suse.com
- Update to 5.0.0:
  Introduction of Cap'n Proto to stabilize the recording format.
  Recordings created in this rr release should be replayable in any
  future rr release.
  New rr pack command makes recordings self-contained.
  Recordings can be made on one machine and replayed on a different
  machine by trapping CPUID instructions when supported on the replay
  machine.
  Brotli compression for smaller traces and lower recording overhead.
  rr replay command line argument -- can be followed by any
  number of arguments to be passed to the debugger.
  rr now chooses replay as the default subcommand if
  the first argument is a directory.
  Performance improvements.
  Syscall support expanded.
  Many bugs fixed.
- Remove: assert_typos.patch and major-minor-macro.patch
* Thu Apr 13 2017 mvetter@suse.com
- Use regular make_install macro. No build directory here.
* Fri Mar 17 2017 mvetter@suse.com
- Add assert_typos.patch:
  Fixes some typos in the tests.
* Fri Mar 17 2017 mvetter@suse.com
- Add major-minor-macro.patch:
  With new glibc version we need to include sys/sysmacros.h
  explicitly.
* Tue Mar  7 2017 mvetter@suse.com
- Initial version of 4.5.0 for openSUSE
